//
// Abstract:
//     SCIPWM Ioctl Sample code
//

#include <windows.h>

#define  NAME  TEXT("Power Management Sample")

#define PWM_IOCTL_POWEROFF      0x1001
#define PWM_IOCTL_SUSPEND       0x1002
#define PWM_IOCTL_RESUME        0x1003
#define PWM_IOCTL_STR           0x1004

// Function prototypes
int ParseCommandLine (TCHAR *lpOpt);
void CloseApp();
BOOL DoInit( HINSTANCE hInstance, int nCmdShow );

DWORD dwIoctlCode = 0x1000;
HWND g_hwndMain;

//
// Main program code
//
int
APIENTRY
WinMain (
         HINSTANCE hInstance,
         HINSTANCE hPrevInstance,
         LPTSTR lpCmdLine,
         int nCmdShow
         )
{
    TCHAR szCmd[80]={0};
    TCHAR szDevName[80];
    HANDLE hFile;
    int i;

    // Copy command line for manipulation
    lstrcpy (szCmd, lpCmdLine);

    if (!ParseCommandLine(szCmd))
        return 1;

    RETAILMSG(1, (TEXT("dwIoctlCode %x\r\n"), dwIoctlCode));
    // Create the main window
    if (!DoInit(hInstance, nCmdShow))
        return 1;

    for ( i = 0; i < 10; i++)
    {
       wsprintf( szDevName, TEXT("SCI%d:"), i);
       hFile = CreateFile(szDevName, GENERIC_WRITE, 0, NULL, OPEN_EXISTING,
                             0, NULL);
       if (hFile != INVALID_HANDLE_VALUE)
           break;
          
    }
              
    if ( i == 10 )
    {
       RETAILMSG(1, (TEXT("Check the driver installed properly\r\n")));
       return 1;
    }

    DeviceIoControl(hFile, dwIoctlCode, NULL, 0, NULL, 0, NULL, NULL);

    CloseHandle(hFile);

//  OutputDebugString(TEXT("CEPlayit exiting.\r\n\r\n"));
    return 0;
}

long FAR PASCAL WindowProc( HWND hWnd, UINT message,
                           WPARAM wParam, LPARAM lParam )
{
    switch( message )
    {
        case WM_DESTROY:
            PostQuitMessage(0);
            return 0;
    }

    return DefWindowProc(hWnd, message, wParam, lParam);
}

BOOL DoInit( HINSTANCE hInstance, int nCmdShow )
{
    ATOM     atomWndClass;
    TCHAR    szTitle[80];

    // set up and register window class
    WNDCLASS wc = {0};
    wc.lpfnWndProc = WindowProc;
    wc.hInstance = hInstance;
    wc.lpszClassName = NAME;
    atomWndClass = RegisterClass( &wc );

    wsprintf(szTitle, TEXT("%s"), NAME);

    // Create a window of zero size that will serve as the sink for
    // keyboard input.  If this media file has a video component, then
    // a second ActiveMovie window will be displayed in which the video
    // will be rendered.  Setting keyboard focus on this application window
    // will allow the user to move the video window around the screen, make
    // it full screen, resize, center, etc. independent of the application
    // window.  If the media file has only an audio component, then this will
    // be the only window created.
    g_hwndMain = CreateWindowEx(
        0,
        NAME,
        szTitle,
        WS_VISIBLE,
        0, 0,
        0, 0,
        NULL,
        NULL,
        hInstance,
        NULL );

    if (!g_hwndMain)
        OutputDebugString(TEXT("*** Failed to create main window!\r\n"));

    return (g_hwndMain != NULL);
}

void CloseApp()
{
    PostMessage(g_hwndMain, WM_CLOSE, 0, 0);
}

void Usage(void)
{
   OutputDebugString(TEXT("/1 Poweroff\r\n"));
   OutputDebugString(TEXT("/2 Suspend\r\n"));
   OutputDebugString(TEXT("/3 Resume\r\n"));
}

int ParseCommandLine (TCHAR *lpOpt)
{
    TCHAR *szArg, szTok[64]={0};
    BOOL fError = FALSE;
    int counter=0;

    // Get first argument
    _tcscpy(szTok, TEXT(" "));
    szArg = _tcstok(lpOpt, szTok);

    // Return if there are no arguments to parse
    if (!szArg)
    {
        return TRUE;
    }

    // Parse command-line arguments
    //do
    //{
        // Check argument to ensure it is valid
        if ((*szArg != TEXT('-')) && (*szArg != TEXT('/')))
        {
            RETAILMSG(1, (TEXT("Invalid argument: %s"), szArg));
            fError = TRUE;
            return FALSE;
        //    break;
        }
        szArg++;

        // Match string with expected value
        switch (towupper(*szArg))
        {
           case TEXT('?'):
               Usage();
               fError = TRUE;
               break;

           case TEXT('1'):
               dwIoctlCode = PWM_IOCTL_POWEROFF;
               break;

           case TEXT('2'):
               dwIoctlCode = PWM_IOCTL_SUSPEND;
               break;

           case TEXT('3'):
               dwIoctlCode = PWM_IOCTL_RESUME;
               break;

           default:
               RETAILMSG(1, (TEXT("Unknown argument: [%s] !!!  Exiting...\r\n"), szArg-1));
               Usage();
               fError = TRUE;
               break;
        }

    //    szArg = _tcstok(NULL, szTok);
    //    counter++;
    //}
    //while( szArg && counter<MAX_ARGS );

    // Success
    return (!fError);
}

